package pps.core.base.service;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.text.CharSequenceUtil;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import pps.cloud.system.service.SysOrganizationCloudService;
import pps.cloud.system.service.data.sys_organization.GetSysOrganizationViewInput;
import pps.cloud.system.service.data.sys_organization.GetSysOrganizationViewOutput;
import pps.core.base.entity.ThirdWeatherDataEnt;
import pps.core.base.mapper.ThirdWeatherDataMapper;
import pps.core.base.service.data.third_weather_data.GetThirdWeatherDataInput;
import pps.core.base.service.data.third_weather_data.GetThirdWeatherDataOutput;
import xstartup.annotation.XService;
import xstartup.annotation.XText;
import xstartup.base.XContext;
import xstartup.base.util.XCopyUtils;
import xstartup.data.XSingleResult;
import xstartup.feature.api.annotation.XApiGet;

import java.math.BigDecimal;

/**
 * 第三方天气模块
 *
 * @author ZWT
 * @date 2024/05/21 11:19
 */
@XText("第三方天气模块")
@XService
public class ThirdWeatherDataService {

    /**
     * 今日天气
     *
     * @param context 上下文
     * @param input   输入
     * @return {@link XSingleResult }<{@link GetThirdWeatherDataOutput }>
     */
    @XText("能耗分析--今日天气")
    @XApiGet
    public XSingleResult<GetThirdWeatherDataOutput> todayWeather(XContext context, GetThirdWeatherDataInput input) {
        GetThirdWeatherDataOutput output;
        GetSysOrganizationViewOutput orgById = this.getOrgById(context, input.getOuId());
        if (ObjectUtil.isNotNull(orgById) && CharSequenceUtil.equals(orgById.getOuName(), "第二采油厂")) {
            ThirdWeatherDataMapper mapper = context.getBean(ThirdWeatherDataMapper.class);
            ThirdWeatherDataEnt ent = mapper.selectOne(new QueryWrapper<ThirdWeatherDataEnt>()
                    .select("wep", "tem", "wns_100m", "dni")
                    .lambda()
                    .ge(ThirdWeatherDataEnt::getForecastTime, DateUtil.date())
                    .orderByAsc(ThirdWeatherDataEnt::getForecastTime)
                    .last("LIMIT 1")
            );
            output = XCopyUtils.copyNewObject(ent, GetThirdWeatherDataOutput.class);
        } else {
            output = GetThirdWeatherDataOutput.builder()
                    .wep(9999)
                    .tem(BigDecimal.ZERO)
                    .wns100m(BigDecimal.ZERO)
                    .dni(BigDecimal.ZERO)
                    .build();
        }
        return XSingleResult.success(output);
    }

    private String getIconPath(Integer wep) {
        switch (wep) {
            case 1000:
                //晴
            case 9000: //高温
                break;
            case 1001: //少云
            case 1002: //多云
                break;
            case 1003: //阴
                break;
            case 1004: //晴间多云
            case 1005: //大部多云
                break;
            case 2000: //雨
            case 2001: //小雨 / 毛毛雨
                break;
            case 2002: //小到中雨
            case 2003: //中雨
                break;
            case 2004: //中到大雨
            case 2005: //大雨
                break;
            case 2006: //大到暴雨
            case 2007: //暴雨
                break;
            case 2008: //暴雨到大暴雨
            case 2009: //大暴雨
            case 2010: //大暴雨到特大暴雨
            case 2011: //特大暴雨
            case 2026: //极端降雨
                break;
            case 2020: //阵雨
            case 2021: //强阵雨
                break;
            case 2022: //雷阵雨
            case 2023: //强雷阵雨
            case 9010: //雷暴
            case 9011: //雷电
                break;
            case 2024: //雷阵雨伴有冰雹
            case 9020: //冰雹
            case 9021: //冰针
            case 9022: //冰粒
                break;
            case 2025: //冻雨
                break;
            case 3000: //雪
            case 3001: //小雪
                break;
            case 3002: //小到中雪
            case 3003: //中雪
                break;
            case 3004: //中到大雪
            case 3005: //大雪
                break;
            case 3006: //大到暴雪
            case 3007: //暴雪
                break;
            case 3020: //阵雪
                break;
            case 3021: //雨雪天气
            case 3022: //雨夹雪
            case 3023: //阵雨夹雪
                break;
            case 4000: //风
            case 4001: //静风
            case 4002: //软风
            case 4003: //轻风
            case 4004: //微风
            case 4005: //和风
            case 4006: //清劲风
            case 4007: //强风
            case 4008: //疾风
            case 4009: //大风
            case 4010: //烈风
            case 4011: //狂风
            case 4012: //暴风
                break;
            case 4013: //飓风
            case 4020: //龙卷风
                break;
            case 4021: //热带风暴
                break;
            case 5000: //雾
            case 5001: //轻雾
            case 5002: //浓雾
            case 5003: //大雾
            case 5004: //强浓雾
            case 5005: //特强浓雾
                break;
            case 5020: //霾
            case 5021: //轻度霾
            case 5022: //中度霾
            case 5023: //重度霾
            case 5024: //严重霾
                break;
            case 6000: //浮尘
            case 6001: //扬沙
                break;
            case 6002: //沙尘暴
            case 6003: //强沙尘暴
                break;
            case 6004: //龙卷
                break;
            case 9001: //低温
                break;
            default:
                //未知
        }
        return null;
    }
    /*-----------------------------------private-----------------------------------*/

    /**
     * 按id获取组织
     *
     * @param context 上下文
     * @param ouId    ou-id
     * @return {@link GetSysOrganizationViewOutput }
     */
    private GetSysOrganizationViewOutput getOrgById(XContext context, String ouId) {
        SysOrganizationCloudService organizationCloudService = context.getBean(SysOrganizationCloudService.class);
        XSingleResult<GetSysOrganizationViewOutput> result = organizationCloudService.getSysOrganizationById(context, GetSysOrganizationViewInput.builder()
                .id(ouId)
                .build());
        result.throwIfFail();
        return result.getResult();
    }
}
